@@ -102,9 +102,12 @@ namespace LongoMatch.Gui
 
 		#region Constructors
 		public MainWindow(IGUIToolkit guiToolkit) :
-		base("LongoMatch")
+		base(Constants.SOFTWARE_NAME)
 		{
+			Screen screen;
+			
 			this.Build();
+			Title = Constants.SOFTWARE_NAME;
 
 			this.guiToolKit = guiToolkit;
 			
@@ -126,26 +129,26 @@ namespace LongoMatch.Gui
 			capturer.CaptureFinished += (sender, e) => {CloseCaptureProject();};
 			
 			buttonswidget.Mode = TagMode.Predifined;
-			localPlayersList.Team = Team.LOCAL;
-			visitorPlayersList.Team = Team.VISITOR;
-			
 			ConnectSignals();
 			ConnectMenuSignals();
 			
 			if (!Config.useGameUnits)
 				GameUnitsViewAction.Visible = false;
 			
+			AddImportEntry(Catalog.GetString("Import file project"), "ImportFileProject",
+			               Constants.PROJECT_NAME + " (" + Constants.PROJECT_EXT + ")",
+			               "*" + Constants.PROJECT_EXT, Project.Import,
+			               false);
+			screen = Display.Default.DefaultScreen;
+			this.Resize(screen.Width * 80 / 100, screen.Height * 80 / 100);
 		}
 
 		#endregion
 		
 		#region Plubic Methods
 		public void AddPlay(Play play) {
-			playsList.AddPlay(play);
-			tagsList.AddPlay(play);
+			playsSelection.AddPlay(play);
 			timeline.AddPlay(play);
-			/* FIXME: Check performance */
-			UpdateTeamsModels();
 			timeline.QueueDraw();
 		}
 		
@@ -160,10 +163,8 @@ namespace LongoMatch.Gui
 		}
 		
 		public void DeletePlays (List<Play> plays) {
-			playsList.RemovePlays(plays);
+			playsSelection.RemovePlays(plays);
 			timeline.RemovePlays(plays);
-			tagsList.RemovePlays(plays);
-			UpdateTeamsModels();
 			timeline.QueueDraw();
 		}
 		
@@ -193,7 +194,7 @@ namespace LongoMatch.Gui
 		
 		public ITemplatesService TemplatesService {
 			set {
-				playsList.TemplatesService = value;
+				playsSelection.TemplatesService = value;
 			}
 		}
 		
@@ -217,6 +218,16 @@ namespace LongoMatch.Gui
 			(parent.Submenu as Menu).Append(item);
 		}
 		
+		public void AddImportEntry (string name, string shortName, string filterName,
+		                            string filter, Func<string, Project> importFunc,
+		                            bool requiresNewFile) {
+			MenuItem parent = (MenuItem) this.UIManager.GetWidget("/menubar1/FileAction/ImportProjectAction");
+			
+			MenuItem item = new MenuItem(name);
+			item.Activated += (sender, e) => (EmitImportProject(name, filterName, filter, importFunc, requiresNewFile));
+			item.Show();
+			(parent.Submenu as Menu).Append(item);
+		}
 		#endregion
 		
 		#region Private Methods
@@ -231,22 +242,15 @@ namespace LongoMatch.Gui
 			timeline.NewMarkEvent += EmitNewTagAtFrame;
 
 			/* Connect TimeNodeChanged events */
-			playsList.TimeNodeChanged += EmitTimeNodeChanged;
-			localPlayersList.TimeNodeChanged += EmitTimeNodeChanged;
-			visitorPlayersList.TimeNodeChanged += EmitTimeNodeChanged;
-			tagsList.TimeNodeChanged += EmitTimeNodeChanged;
 			timeline.TimeNodeChanged += EmitTimeNodeChanged;
 			notes.TimeNodeChanged += EmitTimeNodeChanged;
 
 			/* Connect TimeNodeDeleted events */
-			playsList.TimeNodeDeleted += EmitPlaysDeleted;
+			playsSelection.PlaysDeleted += EmitPlaysDeleted;
 			timeline.TimeNodeDeleted += EmitPlaysDeleted;
 
 			/* Connect TimeNodeSelected events */
-			playsList.TimeNodeSelected += OnTimeNodeSelected;
-			localPlayersList.TimeNodeSelected += OnTimeNodeSelected;
-			visitorPlayersList.TimeNodeSelected += OnTimeNodeSelected;
-			tagsList.TimeNodeSelected += OnTimeNodeSelected;
+			playsSelection.PlaySelected += OnTimeNodeSelected;
 			timeline.TimeNodeSelected += OnTimeNodeSelected;
 
 			/* Connect playlist events */
@@ -257,22 +261,16 @@ namespace LongoMatch.Gui
 			playlist.SavePlaylistEvent += EmitSavePlaylist;
 
 			/* Connect PlayListNodeAdded events */
-			playsList.PlayListNodeAdded += OnPlayListNodeAdded;
-			localPlayersList.PlayListNodeAdded += OnPlayListNodeAdded;
-			visitorPlayersList.PlayListNodeAdded += OnPlayListNodeAdded;
-			tagsList.PlayListNodeAdded += OnPlayListNodeAdded;
+			playsSelection.PlayListNodeAdded += OnPlayListNodeAdded;
 
 			/* Connect tags events */
-			playsList.TagPlay += EmitTagPlay;
+			playsSelection.TagPlay += EmitTagPlay;
 
 			/* Connect SnapshotSeries events */
-			playsList.SnapshotSeriesEvent += EmitSnapshotSeries;
-			localPlayersList.SnapshotSeriesEvent += EmitSnapshotSeries;
-			visitorPlayersList.SnapshotSeriesEvent += EmitSnapshotSeries;
-			tagsList.SnapshotSeriesEvent += EmitSnapshotSeries;
+			playsSelection.SnapshotSeries += EmitSnapshotSeries;
 
 			playlist.RenderPlaylistEvent += EmitRenderPlaylist;
-			playsList.RenderPlaylistEvent += EmitRenderPlaylist;
+			playsSelection.RenderPlaylist += EmitRenderPlaylist;
 			
 			renderingstatebar1.ManageJobs += (e, o) => {EmitManageJobs();};
 			
@@ -291,7 +289,6 @@ namespace LongoMatch.Gui
 		private void ConnectMenuSignals() {
 			SaveProjectAction.Activated += (o, e) => {EmitSaveProject();};
 			CloseProjectAction.Activated += (o, e) => {PromptCloseProject();};
-			ImportProjectAction.Activated += (o, e) => {EmitImportProject();};
 			ExportToProjectFileAction.Activated += (o, e) => {EmitExportProject();};
 			QuitAction.Activated += (o, e) => {CloseAndQuit();};
 			CategoriesTemplatesManagerAction.Activated += (o, e) => {EmitManageCategories();};
@@ -299,11 +296,6 @@ namespace LongoMatch.Gui
 			ProjectsManagerAction.Activated += (o, e) => {EmitManageProjects();};
 		}
 		
-		private void UpdateTeamsModels() {
-			localPlayersList.SetTeam(openedProject.LocalTeamTemplate, openedProject.AllPlays());
-			visitorPlayersList.SetTeam(openedProject.VisitorTeamTemplate, openedProject.AllPlays());
-		}
-		
 		void DetachPlayer (bool detach) {
 			if (detach == detachedPlayer)
 				return;
@@ -351,14 +343,12 @@ namespace LongoMatch.Gui
 			}
 		}
 
-		public void SetProject(Project project, ProjectType projectType, CaptureSettings props)
+		public void SetProject(Project project, ProjectType projectType, CaptureSettings props, PlaysFilter filter)
 		{
 			bool isLive = false;
 			
 			/* Update tabs labels */
 			var desc = project.Description;
-			visitorteamlabel.Text = project.LocalTeamTemplate.TeamName;
-			localteamlabel.Text = project.LocalTeamTemplate.TeamName;
 			
 			ExportProjectAction1.Sensitive = true;
 			
@@ -382,13 +372,8 @@ namespace LongoMatch.Gui
 			openedProject = project;
 			this.projectType = projectType;
 			
-			playsList.ProjectIsLive = isLive;
-			localPlayersList.ProjectIsLive = isLive;
-			visitorPlayersList.ProjectIsLive = isLive;
-			tagsList.ProjectIsLive = isLive;
-			playsList.Project=project;
-			tagsList.Project = project;
-			UpdateTeamsModels();
+			filter.FilterUpdated += OnFilterUpdated;
+			playsSelection.SetProject(project, isLive, filter);
 			buttonswidget.Categories = project.Categories;
 			MakeActionsSensitive(true,projectType);
 			ShowWidgets();
@@ -458,11 +443,7 @@ namespace LongoMatch.Gui
 
 		private void ClearWidgets() {
 			buttonswidget.Categories = null;
-			playsList.Project = null;
-			tagsList.Clear();
-			timeline.Project = null;
-			localPlayersList.Clear();
-			visitorPlayersList.Clear();
+			playsSelection.Clear();
 		}
 
 		private bool PromptCloseProject() {
@@ -541,9 +522,7 @@ namespace LongoMatch.Gui
 		{
 			bool visible = (sender as Gtk.ToggleAction).Active;
 			playlist.Visible=visible;
-			playsList.PlayListLoaded=visible;
-			localPlayersList.PlayListLoaded=visible;
-			visitorPlayersList.PlayListLoaded=visible;
+			playsSelection.PlayListLoaded=visible;
 
 			if(!visible && !notes.Visible) {
 				rightvbox.Visible = false;
@@ -608,6 +587,15 @@ namespace LongoMatch.Gui
 			about.Run();
 			about.Destroy();
 		}
+		
+		protected void OnDialogInfoActionActivated (object sender, System.EventArgs e)
+		{
+			var info = new LongoMatch.Gui.Dialog.ShortcutsHelpDialog();
+			info.TransientFor = this;
+			info.Run();
+			info.Destroy();
+		}
+		
 		#endregion
 
 		protected virtual void OnPlayerbin1Error(object o, string message)
@@ -716,6 +704,10 @@ namespace LongoMatch.Gui
 				" the current project will be closed:")+"\n" + message);
 			EmitCloseOpenedProject(true);
 		}
+		
+		protected virtual void OnFilterUpdated()
+		{
+		}
 		#endregion
 		
 		#region Events
@@ -807,9 +799,10 @@ namespace LongoMatch.Gui
 			ResetGUI();
 		}
 		
-		private void EmitImportProject() {
+		private void EmitImportProject(string name, string filterName, string filter,
+		                               Func<string, Project> func, bool requiresNewFile) {
 			if (ImportProjectEvent != null)
-				ImportProjectEvent();
+				ImportProjectEvent(name, filterName, filter, func, requiresNewFile);
 		}
 		
 		private void EmitOpenProject() {
@@ -887,6 +880,8 @@ namespace LongoMatch.Gui
 			if (KeyPressed != null)
 				KeyPressed(sender, key, modifier);
 		}
+
+
 		#endregion
 	}
 }
