@@ -154,11 +154,12 @@ namespace LongoMatch.Services
 		private static void SetupBaseDir() {
 			string home;
 			
-			if (Environment.OSVersion.Platform == PlatformID.Win32NT) {
-				Config.baseDirectory = System.IO.Path.Combine(System.AppDomain.CurrentDomain.BaseDirectory,"../");
+			Config.baseDirectory = System.IO.Path.Combine(System.AppDomain.CurrentDomain.BaseDirectory,"../");
+			if (!System.IO.Directory.Exists(System.IO.Path.Combine(Config.baseDirectory, "share", "longomatch"))) {
+				Config.baseDirectory = System.IO.Path.Combine(Config.baseDirectory, "../");
 			}
-			else
-				Config.baseDirectory = System.IO.Path.Combine(System.AppDomain.CurrentDomain.BaseDirectory,"../../");
+			if (!System.IO.Directory.Exists(System.IO.Path.Combine(Config.baseDirectory, "share", "longomatch")))
+				Log.Warning("Prefix directory not found");
 			
 			/* Check for the magic file PORTABLE to check if it's a portable version
 			 * and the config goes in the same folder as the binaries */
@@ -171,7 +172,8 @@ namespace LongoMatch.Services
 			if (Environment.OSVersion.Platform == PlatformID.Win32NT)
 				Config.configDirectory = Config.homeDirectory;
 			else
-				Config.configDirectory = System.IO.Path.Combine(home,".longomatch");
+				Config.configDirectory = System.IO.Path.Combine(home,"." +
+					Constants.SOFTWARE_NAME.ToLower());
 		}
 
 		private static bool? debugging = null;	
